<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>DecoderSndFileFactory</name>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="66"/>
        <source>Sndfile Plugin</source>
        <translation>Sndfile-Modul</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="68"/>
        <source>PCM Files</source>
        <translation>PCM-Dateien</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="136"/>
        <source>About Sndfile Audio Plugin</source>
        <translation>Über Sndfile-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="137"/>
        <source>Qmmp Sndfile Audio Plugin</source>
        <translation>Qmmp Sndfile-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="138"/>
        <source>Compiled against</source>
        <translation>Kompiliert gegen</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="139"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
